package example.codes;

import com.silanis.esl.sdk.*;
import com.silanis.esl.sdk.builder.DocumentBuilder;
import com.silanis.esl.sdk.builder.PackageBuilder;
import com.silanis.esl.sdk.builder.SignatureBuilder;
import com.silanis.esl.sdk.builder.SignerBuilder;
import com.silanis.esl.sdk.builder.TextAnchorBuilder;

public class SignDocuments {
	
	private static String key = "api_key";
	private static String url = "https://sandbox.esignlive.com/api";

	public static void main(String[] args) {
		
		EslClient client = new EslClient(key, url);
		
		//Package
		PackageBuilder packageToBuild = PackageBuilder.newPackageNamed("Sign Documents Test");
		
		//Sender
		SignerBuilder signer1 = SignerBuilder.newSignerWithEmail("sender@example.com")
				.withFirstName("Haris")
				.withLastName("Haidary")
				.withCustomId("Sender");
		//Client
		SignerBuilder signer2 = SignerBuilder.newSignerWithEmail("signer@example.com")
				.withFirstName("John")
				.withLastName("Smith")
				.withCustomId("Signer");
		
		//Signatures
		SignatureBuilder signature1 = SignatureBuilder.signatureFor("sender@example.com")
				.withPositionAnchor(TextAnchorBuilder.newTextAnchor("Signature of the Contractor")
                        .atPosition(TextAnchorPosition.TOPLEFT)
                        .withSize(150, 40)
                        .withOffset(0, -50)
                        .withCharacter(0)
                        .withOccurence(0));
		
		SignatureBuilder signature2 = SignatureBuilder.signatureFor("signer@example.com")
				.withPositionAnchor(TextAnchorBuilder.newTextAnchor("Signature of the Client")
                        .atPosition(TextAnchorPosition.TOPLEFT)
                        .withSize(150, 40)
                        .withOffset(0, -50)
                        .withCharacter(0)
                        .withOccurence(0));
		
		
		//Document
		DocumentBuilder document1 = DocumentBuilder.newDocumentWithName("Cleaning Contract")
				.fromFile("DOC_FILE_PATH")
				.withSignature(signature1)
				.withSignature(signature2);
		
		
		//Build package
		DocumentPackage packageToSend = packageToBuild.withSigner(signer1).withSigner(signer2).withDocument(document1).build();
		
		PackageId packageId = client.createAndSendPackage(packageToSend);
		
		client.signDocuments(packageId);
		
	}

}
